@@ -205,7 +205,7 @@ int SensorDataModel::columnCount(const QModelIndex &parent) const
         return 0;
     }
 
-    return d->sensors.count();
+    return d->sensorInfos.count();
 }
 
 qreal SensorDataModel::minimum() const
@@ -296,7 +296,7 @@ void SensorDataModel::setSensorColors(const QVariantMap &sensorColors)
 
 bool KSysGuard::SensorDataModel::isReady() const
 {
-    return d->sensors.size() == d->requestedSensors.size();
+    return d->sensors.size() == d->sensorInfos.size();
 }
 
 void SensorDataModel::addSensor(const QString &sensorId)
@@ -407,7 +407,10 @@ void SensorDataModel::onMetaDataChanged(const QString &sensorId, const SensorInf
 
     SensorDaemonInterface::instance()->requestValue(sensorId);
     emit sensorMetaDataChanged();
-    Q_EMIT readyChanged();
+
+    if (isReady()) {
+        Q_EMIT readyChanged();
+    }
 }
 
 void SensorDataModel::onValueChanged(const QString &sensorId, const QVariant &value)
@@ -433,10 +436,6 @@ void SensorDataModel::Private::sensorsChanged()
 
     sensors = requestedSensors;
 
-    for (const auto& sensor : sensors) {
-        sensorInfos[sensor] = KSysGuard::SensorInfo();
-    }
-
     SensorDaemonInterface::instance()->subscribe(requestedSensors);
     SensorDaemonInterface::instance()->requestMetaData(requestedSensors);
 
